You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by vo...@apache.org on 2017/03/21 09:24:14 UTC

[23/71] [abbrv] ignite git commit: ignite-3207 Rename IgniteConfiguration.gridName -> igniteInstanceName.

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/clients/src/test/java/org/apache/ignite/internal/processors/rest/TaskCommandHandlerSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/apache/ignite/internal/processors/rest/TaskCommandHandlerSelfTest.java b/modules/clients/src/test/java/org/apache/ignite/internal/processors/rest/TaskCommandHandlerSelfTest.java
index dc424fe..7f47e77 100644
--- a/modules/clients/src/test/java/org/apache/ignite/internal/processors/rest/TaskCommandHandlerSelfTest.java
+++ b/modules/clients/src/test/java/org/apache/ignite/internal/processors/rest/TaskCommandHandlerSelfTest.java
@@ -101,8 +101,8 @@ public class TaskCommandHandlerSelfTest extends GridCommonAbstractTest {
     }
 
     /** {@inheritDoc} */
-    @Override protected IgniteConfiguration getConfiguration(String gridName) throws Exception {
-        IgniteConfiguration cfg = super.getConfiguration(gridName);
+    @Override protected IgniteConfiguration getConfiguration(String igniteInstanceName) throws Exception {
+        IgniteConfiguration cfg = super.getConfiguration(igniteInstanceName);
 
         cfg.setLocalHost(HOST);
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/clients/src/test/java/org/apache/ignite/internal/processors/rest/protocols/tcp/redis/RedisProtocolSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/apache/ignite/internal/processors/rest/protocols/tcp/redis/RedisProtocolSelfTest.java b/modules/clients/src/test/java/org/apache/ignite/internal/processors/rest/protocols/tcp/redis/RedisProtocolSelfTest.java
index 59cbe76..79896ea 100644
--- a/modules/clients/src/test/java/org/apache/ignite/internal/processors/rest/protocols/tcp/redis/RedisProtocolSelfTest.java
+++ b/modules/clients/src/test/java/org/apache/ignite/internal/processors/rest/protocols/tcp/redis/RedisProtocolSelfTest.java
@@ -80,8 +80,8 @@ public class RedisProtocolSelfTest extends GridCommonAbstractTest {
     }
 
     /** {@inheritDoc} */
-    @Override protected IgniteConfiguration getConfiguration(String gridName) throws Exception {
-        IgniteConfiguration cfg = super.getConfiguration(gridName);
+    @Override protected IgniteConfiguration getConfiguration(String igniteInstanceName) throws Exception {
+        IgniteConfiguration cfg = super.getConfiguration(igniteInstanceName);
 
         cfg.setLocalHost(HOST);
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcComplexQuerySelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcComplexQuerySelfTest.java b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcComplexQuerySelfTest.java
index ec41a38..e5cd09b 100644
--- a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcComplexQuerySelfTest.java
+++ b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcComplexQuerySelfTest.java
@@ -51,8 +51,8 @@ public class JdbcComplexQuerySelfTest extends GridCommonAbstractTest {
     private Statement stmt;
 
     /** {@inheritDoc} */
-    @Override protected IgniteConfiguration getConfiguration(String gridName) throws Exception {
-        IgniteConfiguration cfg = super.getConfiguration(gridName);
+    @Override protected IgniteConfiguration getConfiguration(String igniteInstanceName) throws Exception {
+        IgniteConfiguration cfg = super.getConfiguration(igniteInstanceName);
 
         CacheConfiguration<?,?> cache = defaultCacheConfiguration();
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcConnectionSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcConnectionSelfTest.java b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcConnectionSelfTest.java
index b414f67..cc06180 100644
--- a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcConnectionSelfTest.java
+++ b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcConnectionSelfTest.java
@@ -51,8 +51,8 @@ public class JdbcConnectionSelfTest extends GridCommonAbstractTest {
     private static final String HOST = "127.0.0.1";
 
     /** {@inheritDoc} */
-    @Override protected IgniteConfiguration getConfiguration(String gridName) throws Exception {
-        IgniteConfiguration cfg = super.getConfiguration(gridName);
+    @Override protected IgniteConfiguration getConfiguration(String igniteInstanceName) throws Exception {
+        IgniteConfiguration cfg = super.getConfiguration(igniteInstanceName);
 
         cfg.setCacheConfiguration(cacheConfiguration(null), cacheConfiguration(CUSTOM_CACHE_NAME));
 
@@ -66,7 +66,7 @@ public class JdbcConnectionSelfTest extends GridCommonAbstractTest {
 
         ConnectorConfiguration clientCfg = new ConnectorConfiguration();
 
-        if (!gridName.endsWith("0"))
+        if (!igniteInstanceName.endsWith("0"))
             clientCfg.setPort(CUSTOM_PORT);
 
         cfg.setConnectorConfiguration(clientCfg);

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcEmptyCacheSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcEmptyCacheSelfTest.java b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcEmptyCacheSelfTest.java
index 11a57db..42e307f 100644
--- a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcEmptyCacheSelfTest.java
+++ b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcEmptyCacheSelfTest.java
@@ -48,8 +48,8 @@ public class JdbcEmptyCacheSelfTest extends GridCommonAbstractTest {
     private Statement stmt;
 
     /** {@inheritDoc} */
-    @Override protected IgniteConfiguration getConfiguration(String gridName) throws Exception {
-        IgniteConfiguration cfg = super.getConfiguration(gridName);
+    @Override protected IgniteConfiguration getConfiguration(String igniteInstanceName) throws Exception {
+        IgniteConfiguration cfg = super.getConfiguration(igniteInstanceName);
 
         CacheConfiguration cache = defaultCacheConfiguration();
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcLocalCachesSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcLocalCachesSelfTest.java b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcLocalCachesSelfTest.java
index 0ab2bf7..d959f3f 100644
--- a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcLocalCachesSelfTest.java
+++ b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcLocalCachesSelfTest.java
@@ -48,8 +48,8 @@ public class JdbcLocalCachesSelfTest extends GridCommonAbstractTest {
     private static final String URL = "jdbc:ignite://127.0.0.1/" + CACHE_NAME;
 
     /** {@inheritDoc} */
-    @Override protected IgniteConfiguration getConfiguration(String gridName) throws Exception {
-        IgniteConfiguration cfg = super.getConfiguration(gridName);
+    @Override protected IgniteConfiguration getConfiguration(String igniteInstanceName) throws Exception {
+        IgniteConfiguration cfg = super.getConfiguration(igniteInstanceName);
 
         CacheConfiguration cache = defaultCacheConfiguration();
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcMetadataSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcMetadataSelfTest.java b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcMetadataSelfTest.java
index d8226be..48ed548 100644
--- a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcMetadataSelfTest.java
+++ b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcMetadataSelfTest.java
@@ -55,8 +55,8 @@ public class JdbcMetadataSelfTest extends GridCommonAbstractTest {
     private static final String URL = "jdbc:ignite://127.0.0.1/";
 
     /** {@inheritDoc} */
-    @Override protected IgniteConfiguration getConfiguration(String gridName) throws Exception {
-        IgniteConfiguration cfg = super.getConfiguration(gridName);
+    @Override protected IgniteConfiguration getConfiguration(String igniteInstanceName) throws Exception {
+        IgniteConfiguration cfg = super.getConfiguration(igniteInstanceName);
 
         CacheConfiguration<?,?> cache = defaultCacheConfiguration();
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcNoDefaultCacheTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcNoDefaultCacheTest.java b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcNoDefaultCacheTest.java
index 48748ba..1506295 100644
--- a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcNoDefaultCacheTest.java
+++ b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcNoDefaultCacheTest.java
@@ -52,8 +52,8 @@ public class JdbcNoDefaultCacheTest extends GridCommonAbstractTest {
     private static final int GRID_CNT = 2;
 
     /** {@inheritDoc} */
-    @Override protected IgniteConfiguration getConfiguration(String gridName) throws Exception {
-        IgniteConfiguration cfg = super.getConfiguration(gridName);
+    @Override protected IgniteConfiguration getConfiguration(String igniteInstanceName) throws Exception {
+        IgniteConfiguration cfg = super.getConfiguration(igniteInstanceName);
 
         cfg.setCacheConfiguration(cacheConfiguration(CACHE1_NAME), cacheConfiguration(CACHE2_NAME));
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcPreparedStatementSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcPreparedStatementSelfTest.java b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcPreparedStatementSelfTest.java
index 0c701ef..5351b6a 100644
--- a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcPreparedStatementSelfTest.java
+++ b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcPreparedStatementSelfTest.java
@@ -71,8 +71,8 @@ public class JdbcPreparedStatementSelfTest extends GridCommonAbstractTest {
     private PreparedStatement stmt;
 
     /** {@inheritDoc} */
-    @Override protected IgniteConfiguration getConfiguration(String gridName) throws Exception {
-        IgniteConfiguration cfg = super.getConfiguration(gridName);
+    @Override protected IgniteConfiguration getConfiguration(String igniteInstanceName) throws Exception {
+        IgniteConfiguration cfg = super.getConfiguration(igniteInstanceName);
 
         CacheConfiguration<?,?> cache = defaultCacheConfiguration();
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcResultSetSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcResultSetSelfTest.java b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcResultSetSelfTest.java
index 7b077fc..05f7f04 100644
--- a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcResultSetSelfTest.java
+++ b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcResultSetSelfTest.java
@@ -66,8 +66,8 @@ public class JdbcResultSetSelfTest extends GridCommonAbstractTest {
     private Statement stmt;
 
     /** {@inheritDoc} */
-    @Override protected IgniteConfiguration getConfiguration(String gridName) throws Exception {
-        IgniteConfiguration cfg = super.getConfiguration(gridName);
+    @Override protected IgniteConfiguration getConfiguration(String igniteInstanceName) throws Exception {
+        IgniteConfiguration cfg = super.getConfiguration(igniteInstanceName);
 
         CacheConfiguration<?,?> cache = defaultCacheConfiguration();
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcStatementSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcStatementSelfTest.java b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcStatementSelfTest.java
index 352b819..eb77ec6 100644
--- a/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcStatementSelfTest.java
+++ b/modules/clients/src/test/java/org/apache/ignite/jdbc/JdbcStatementSelfTest.java
@@ -56,8 +56,8 @@ public class JdbcStatementSelfTest extends GridCommonAbstractTest {
     private Statement stmt;
 
     /** {@inheritDoc} */
-    @Override protected IgniteConfiguration getConfiguration(String gridName) throws Exception {
-        IgniteConfiguration cfg = super.getConfiguration(gridName);
+    @Override protected IgniteConfiguration getConfiguration(String igniteInstanceName) throws Exception {
+        IgniteConfiguration cfg = super.getConfiguration(igniteInstanceName);
 
         CacheConfiguration<?,?> cache = defaultCacheConfiguration();
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/clients/src/test/resources/spring-server-node.xml
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/resources/spring-server-node.xml b/modules/clients/src/test/resources/spring-server-node.xml
index f52640b..093b35d 100644
--- a/modules/clients/src/test/resources/spring-server-node.xml
+++ b/modules/clients/src/test/resources/spring-server-node.xml
@@ -58,7 +58,7 @@
         GridJobStealingCollisionSpi and GridJobStealingFailoverSPI.
     -->
     <bean id="grid.cfg" class="org.apache.ignite.configuration.IgniteConfiguration">
-        <property name="gridName" value="node"/>
+        <property name="igniteInstanceName" value="node"/>
 
         <!-- Set to local host address. -->
         <property name="localHost" value="127.0.0.1"/>

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/clients/src/test/resources/spring-server-ssl-node.xml
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/resources/spring-server-ssl-node.xml b/modules/clients/src/test/resources/spring-server-ssl-node.xml
index 073ac65..98b5e1f 100644
--- a/modules/clients/src/test/resources/spring-server-ssl-node.xml
+++ b/modules/clients/src/test/resources/spring-server-ssl-node.xml
@@ -54,7 +54,7 @@
         GridJobStealingCollisionSpi and GridJobStealingFailoverSPI.
     -->
     <bean id="grid.cfg" class="org.apache.ignite.configuration.IgniteConfiguration">
-        <property name="gridName" value="sslnode"/>
+        <property name="igniteInstanceName" value="sslnode"/>
 
         <!-- Set to local host address. -->
         <property name="localHost" value="127.0.0.1"/>

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/core/src/main/java/org/apache/ignite/Ignite.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/Ignite.java b/modules/core/src/main/java/org/apache/ignite/Ignite.java
index 7f8974c..bee4d31 100644
--- a/modules/core/src/main/java/org/apache/ignite/Ignite.java
+++ b/modules/core/src/main/java/org/apache/ignite/Ignite.java
@@ -65,16 +65,13 @@ import org.jetbrains.annotations.Nullable;
  */
 public interface Ignite extends AutoCloseable {
     /**
-     * Gets the name of the grid this grid instance (and correspondingly its local node) belongs to.
-     * Note that single Java VM can have multiple grid instances all belonging to different grids. Grid
-     * name allows to indicate to what grid this particular grid instance (i.e. grid runtime and its
-     * local node) belongs to.
+     * Gets the name of the Ignite instance.
+     * The name allows having multiple Ignite instances with different names within the same Java VM.
      * <p>
-     * If default grid instance is used, then
-     * {@code null} is returned. Refer to {@link Ignition} documentation
-     * for information on how to start named grids.
+     * If default Ignite instance is used, then {@code null} is returned.
+     * Refer to {@link Ignition} documentation for information on how to start named ignite Instances.
      *
-     * @return Name of the grid, or {@code null} for default grid.
+     * @return Name of the Ignite instance, or {@code null} for default Ignite instance.
      */
     public String name();
 
@@ -582,7 +579,7 @@ public interface Ignite extends AutoCloseable {
 
     /**
      * Closes {@code this} instance of grid. This method is identical to calling
-     * {@link G#stop(String, boolean) G.stop(gridName, true)}.
+     * {@link G#stop(String, boolean) G.stop(igniteInstanceName, true)}.
      * <p>
      * The method is invoked automatically on objects managed by the
      * {@code try-with-resources} statement.

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/core/src/main/java/org/apache/ignite/IgniteSystemProperties.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/IgniteSystemProperties.java b/modules/core/src/main/java/org/apache/ignite/IgniteSystemProperties.java
index 47a66fe..3c73bd5 100644
--- a/modules/core/src/main/java/org/apache/ignite/IgniteSystemProperties.java
+++ b/modules/core/src/main/java/org/apache/ignite/IgniteSystemProperties.java
@@ -34,10 +34,18 @@ import org.jetbrains.annotations.Nullable;
 public final class IgniteSystemProperties {
     /**
      * If this system property is present the Ignite will include grid name into verbose log.
+     *
+     * @deprecated Use {@link #IGNITE_LOG_INSTANCE_NAME}.
      */
+    @Deprecated
     public static final String IGNITE_LOG_GRID_NAME = "IGNITE_LOG_GRID_NAME";
 
     /**
+     * If this system property is present the Ignite will include instance name into verbose log.
+     */
+    public static final String IGNITE_LOG_INSTANCE_NAME = "IGNITE_LOG_INSTANCE_NAME";
+
+    /**
      * This property is used internally to pass an exit code to loader when
      * Ignite instance is being restarted.
      */

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/core/src/main/java/org/apache/ignite/Ignition.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/Ignition.java b/modules/core/src/main/java/org/apache/ignite/Ignition.java
index b4c01f9..1bdd58d 100644
--- a/modules/core/src/main/java/org/apache/ignite/Ignition.java
+++ b/modules/core/src/main/java/org/apache/ignite/Ignition.java
@@ -57,11 +57,11 @@ import org.jetbrains.annotations.Nullable;
  * </pre>
  * Here is how a grid instance can be configured from Spring XML configuration file. The
  * example below configures a grid instance with additional user attributes
- * (see {@link org.apache.ignite.cluster.ClusterNode#attributes()}) and specifies a grid name:
+ * (see {@link org.apache.ignite.cluster.ClusterNode#attributes()}) and specifies a Ignite instance name:
  * <pre name="code" class="xml">
  * &lt;bean id="grid.cfg" class="org.apache.ignite.configuration.IgniteConfiguration"&gt;
  *     ...
- *     &lt;property name="gridName" value="grid"/&gt;
+ *     &lt;property name="igniteInstanceName" value="grid"/&gt;
  *     &lt;property name="userAttributes"&gt;
  *         &lt;map&gt;
  *             &lt;entry key="group" value="worker"/&gt;
@@ -175,12 +175,12 @@ public class Ignition {
     }
 
     /**
-     * Gets states of named grid. If name is {@code null}, then state of
-     * default no-name grid is returned.
+     * Gets states of named Ignite instance. If name is {@code null}, then state of
+     * default no-name Ignite instance is returned.
      *
-     * @param name Grid name. If name is {@code null}, then state of
-     *      default no-name grid is returned.
-     * @return Grid state.
+     * @param name Ignite instance name. If name is {@code null}, then state of
+     *      default no-name Ignite instance is returned.
+     * @return Ignite instance state.
      */
     public static IgniteState state(@Nullable String name) {
         return IgnitionEx.state(name);
@@ -202,13 +202,13 @@ public class Ignition {
     }
 
     /**
-     * Stops named grid. If {@code cancel} flag is set to {@code true} then
+     * Stops named Ignite instance. If {@code cancel} flag is set to {@code true} then
      * all jobs currently executing on local node will be interrupted. If
-     * grid name is {@code null}, then default no-name grid will be stopped.
-     * If wait parameter is set to {@code true} then grid will wait for all
+     * Ignite instance name is {@code null}, then default no-name Ignite instance will be stopped.
+     * If wait parameter is set to {@code true} then Ignite instance will wait for all
      * tasks to be finished.
      *
-     * @param name Grid name. If {@code null}, then default no-name grid will
+     * @param name Ignite instance name. If {@code null}, then default no-name Ignite instance will
      *      be stopped.
      * @param cancel If {@code true} then all jobs currently will be cancelled
      *      by calling {@link org.apache.ignite.compute.ComputeJob#cancel()} method. Note that just like with
@@ -216,7 +216,7 @@ public class Ignition {
      *      execution. If {@code false}, then jobs currently running will not be
      *      canceled. In either case, grid node will wait for completion of all
      *      jobs running on it before stopping.
-     * @return {@code true} if named grid instance was indeed found and stopped,
+     * @return {@code true} if named Ignite instance was indeed found and stopped,
      *      {@code false} otherwise (the instance with given {@code name} was
      *      not found).
      */
@@ -514,20 +514,17 @@ public class Ignition {
     }
 
     /**
-     * Gets an named grid instance. If grid name is {@code null} or empty string,
-     * then default no-name grid will be returned. Note that caller of this method
+     * Gets a named Ignite instance. If Ignite instance name is {@code null} or empty string,
+     * then default no-name Ignite instance will be returned. Note that caller of this method
      * should not assume that it will return the same instance every time.
      * <p>
-     * Note that Java VM can run multiple grid instances and every grid instance (and its
-     * node) can belong to a different grid. Grid name defines what grid a particular grid
-     * instance (and correspondingly its node) belongs to.
+     * The name allows having multiple Ignite instances with different names within the same Java VM.
      *
-     * @param name Grid name to which requested grid instance belongs to. If {@code null},
-     *      then grid instance belonging to a default no-name grid will be returned.
-     * @return An instance of named grid. This method never returns
-     *      {@code null}.
-     * @throws IgniteIllegalStateException Thrown if default grid was not properly
-     *      initialized or grid instance was stopped or was not started.
+     * @param name Ignite instance name. If {@code null}, then a default no-name
+     *      Ignite instance will be returned.
+     * @return A named Ignite instance. This method never returns {@code null}.
+     * @throws IgniteIllegalStateException Thrown if default Ignite instance was not properly
+     *      initialized or Ignite instance was stopped or was not started.
      */
     public static Ignite ignite(@Nullable String name) throws IgniteIllegalStateException {
         return IgnitionEx.grid(name);

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/core/src/main/java/org/apache/ignite/IgnitionListener.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/IgnitionListener.java b/modules/core/src/main/java/org/apache/ignite/IgnitionListener.java
index 0a709fb..b6a026f 100644
--- a/modules/core/src/main/java/org/apache/ignite/IgnitionListener.java
+++ b/modules/core/src/main/java/org/apache/ignite/IgnitionListener.java
@@ -29,7 +29,7 @@ public interface IgnitionListener extends EventListener {
     /**
      * Listener for grid factory state change notifications.
      *
-     * @param name Grid name ({@code null} for default un-named grid).
+     * @param name Ignite instance name ({@code null} for default un-named Ignite instance).
      * @param state New state.
      */
     public void onStateChange(@Nullable String name, IgniteState state);

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/core/src/main/java/org/apache/ignite/cache/CacheManager.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/cache/CacheManager.java b/modules/core/src/main/java/org/apache/ignite/cache/CacheManager.java
index 6e09d72..97409fa 100644
--- a/modules/core/src/main/java/org/apache/ignite/cache/CacheManager.java
+++ b/modules/core/src/main/java/org/apache/ignite/cache/CacheManager.java
@@ -107,7 +107,7 @@ public class CacheManager implements javax.cache.CacheManager {
                     cfg.setDiscoverySpi(discoSpi);
                 }
 
-                cfg.setGridName("CacheManager_" + igniteCnt.getAndIncrement());
+                cfg.setIgniteInstanceName("CacheManager_" + igniteCnt.getAndIncrement());
 
                 cfg.setClassLoader(clsLdr);
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/core/src/main/java/org/apache/ignite/compute/gridify/Gridify.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/compute/gridify/Gridify.java b/modules/core/src/main/java/org/apache/ignite/compute/gridify/Gridify.java
index 3cf1b73..93e91db 100644
--- a/modules/core/src/main/java/org/apache/ignite/compute/gridify/Gridify.java
+++ b/modules/core/src/main/java/org/apache/ignite/compute/gridify/Gridify.java
@@ -184,7 +184,17 @@ public @interface Gridify {
     /**
      * Name of the grid to use. By default, no-name default grid is used.
      * Refer to {@link org.apache.ignite.Ignition} for information about named grids.
+     *
+     * @deprecated Use {@link #igniteInstanceName()}. Nonempty {@link #igniteInstanceName()} takes precedence.
      */
     @SuppressWarnings({"JavaDoc"})
+    @Deprecated
     String gridName() default "";
+
+    /**
+     * Name of the Ignite instance to use. By default, no-name default Ignite instance is used.
+     * Refer to {@link org.apache.ignite.Ignition} for information about named Ignite instances.
+     */
+    @SuppressWarnings({"JavaDoc"})
+    String igniteInstanceName() default "";
 }
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/core/src/main/java/org/apache/ignite/compute/gridify/GridifySetToSet.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/compute/gridify/GridifySetToSet.java b/modules/core/src/main/java/org/apache/ignite/compute/gridify/GridifySetToSet.java
index 9b57c43..635f28d 100644
--- a/modules/core/src/main/java/org/apache/ignite/compute/gridify/GridifySetToSet.java
+++ b/modules/core/src/main/java/org/apache/ignite/compute/gridify/GridifySetToSet.java
@@ -198,6 +198,16 @@ public @interface GridifySetToSet {
     /**
      * Name of the grid to use. By default, no-name default grid is used.
      * Refer to {@link org.apache.ignite.Ignition} for information about named grids.
+     *
+     * @deprecated Use {@link #igniteInstanceName()}. Nonempty {@link #igniteInstanceName()} takes precedence.
      */
+    @Deprecated
     String gridName() default "";
+
+    /**
+     * Name of the Ignite instance to use. By default, no-name default Ignite instance is used.
+     * Refer to {@link org.apache.ignite.Ignition} for information about named Ignite instances.
+     */
+    @SuppressWarnings({"JavaDoc"})
+    String igniteInstanceName() default "";
 }
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/core/src/main/java/org/apache/ignite/compute/gridify/GridifySetToValue.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/compute/gridify/GridifySetToValue.java b/modules/core/src/main/java/org/apache/ignite/compute/gridify/GridifySetToValue.java
index 96f17b2..34590d4 100644
--- a/modules/core/src/main/java/org/apache/ignite/compute/gridify/GridifySetToValue.java
+++ b/modules/core/src/main/java/org/apache/ignite/compute/gridify/GridifySetToValue.java
@@ -196,6 +196,16 @@ public @interface GridifySetToValue {
     /**
      * Name of the grid to use. By default, no-name default grid is used.
      * Refer to {@link org.apache.ignite.Ignition} for information about named grids.
+     *
+     * @deprecated Use {@link #igniteInstanceName()}. Nonempty {@link #igniteInstanceName()} takes precedence.
      */
+    @Deprecated
     String gridName() default "";
+
+    /**
+     * Name of the Ignite instance to use. By default, no-name default Ignite instance is used.
+     * Refer to {@link org.apache.ignite.Ignition} for information about named Ignite instances.
+     */
+    @SuppressWarnings({"JavaDoc"})
+    String igniteInstanceName() default "";
 }
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/core/src/main/java/org/apache/ignite/configuration/IgniteConfiguration.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/configuration/IgniteConfiguration.java b/modules/core/src/main/java/org/apache/ignite/configuration/IgniteConfiguration.java
index f35742b..5b3dcc9 100644
--- a/modules/core/src/main/java/org/apache/ignite/configuration/IgniteConfiguration.java
+++ b/modules/core/src/main/java/org/apache/ignite/configuration/IgniteConfiguration.java
@@ -227,8 +227,8 @@ public class IgniteConfiguration {
     @SuppressWarnings("UnnecessaryBoxing")
     public static final Long DFLT_FAILURE_DETECTION_TIMEOUT = new Long(10_000);
 
-    /** Optional grid name. */
-    private String gridName;
+    /** Optional local Ignite instance name. */
+    private String igniteInstanceName;
 
     /** User attributes. */
     private Map<String, ?> userAttrs;
@@ -509,26 +509,26 @@ public class IgniteConfiguration {
         allResolversPassReq = cfg.isAllSegmentationResolversPassRequired();
         atomicCfg = cfg.getAtomicConfiguration();
         binaryCfg = cfg.getBinaryConfiguration();
-        daemon = cfg.isDaemon();
         cacheCfg = cfg.getCacheConfiguration();
         cacheKeyCfg = cfg.getCacheKeyConfiguration();
         cacheSanityCheckEnabled = cfg.isCacheSanityCheckEnabled();
         callbackPoolSize = cfg.getAsyncCallbackPoolSize();
-        connectorCfg = cfg.getConnectorConfiguration();
         classLdr = cfg.getClassLoader();
         clientMode = cfg.isClientMode();
         clockSyncFreq = cfg.getClockSyncFrequency();
         clockSyncSamples = cfg.getClockSyncSamples();
+        connectorCfg = cfg.getConnectorConfiguration();
         consistentId = cfg.getConsistentId();
+        daemon = cfg.isDaemon();
         dataStreamerPoolSize = cfg.getDataStreamerThreadPoolSize();
         deployMode = cfg.getDeploymentMode();
         discoStartupDelay = cfg.getDiscoveryStartupDelay();
         failureDetectionTimeout = cfg.getFailureDetectionTimeout();
-        gridName = cfg.getGridName();
         hadoopCfg = cfg.getHadoopConfiguration();
         igfsCfg = cfg.getFileSystemConfiguration();
         igfsPoolSize = cfg.getIgfsThreadPoolSize();
         igniteHome = cfg.getIgniteHome();
+        igniteInstanceName = cfg.getIgniteInstanceName();
         igniteWorkDir = cfg.getWorkDirectory();
         inclEvtTypes = cfg.getIncludeEventTypes();
         includeProps = cfg.getIncludeProperties();
@@ -540,8 +540,8 @@ public class IgniteConfiguration {
         marsh = cfg.getMarshaller();
         marshLocJobs = cfg.isMarshalLocalJobs();
         mbeanSrv = cfg.getMBeanServer();
-        metricsHistSize = cfg.getMetricsHistorySize();
         metricsExpTime = cfg.getMetricsExpireTime();
+        metricsHistSize = cfg.getMetricsHistorySize();
         metricsLogFreq = cfg.getMetricsLogFrequency();
         metricsUpdateFreq = cfg.getMetricsUpdateFrequency();
         mgmtPoolSize = cfg.getManagementThreadPoolSize();
@@ -581,12 +581,27 @@ public class IgniteConfiguration {
     /**
      * Gets optional grid name. Returns {@code null} if non-default grid name was not
      * provided.
+     * <p>The name only works locally and has no effect on topology</p>
      *
      * @return Optional grid name. Can be {@code null}, which is default grid name, if
      *      non-default grid name was not provided.
+     * @deprecated Use {@link #getIgniteInstanceName()} instead.
      */
+    @Deprecated
     public String getGridName() {
-        return gridName;
+        return getIgniteInstanceName();
+    }
+
+    /**
+     * Gets optional local instance name. Returns {@code null} if non-default local instance
+     * name was not provided.
+     * <p>The name only works locally and has no effect on topology</p>
+     *
+     * @return Optional local instance name. Can be {@code null}, which is default local
+     * instance name, if non-default local instance name was not provided.
+     */
+    public String getIgniteInstanceName() {
+        return igniteInstanceName;
     }
 
     /**
@@ -635,9 +650,22 @@ public class IgniteConfiguration {
      * @param gridName Grid name to set. Can be {@code null}, which is default
      *      grid name.
      * @return {@code this} for chaining.
+     * @deprecated Use {@link #setIgniteInstanceName(String)} instead.
      */
+    @Deprecated
     public IgniteConfiguration setGridName(String gridName) {
-        this.gridName = gridName;
+        return setIgniteInstanceName(gridName);
+    }
+
+    /**
+     * Sets of local instance name. Note that {@code null} is a default local instance name.
+     *
+     * @param instanceName Local instance name to set. Can be {@code null}. which is default
+     * local instance name.
+     * @return {@code this} for chaining.
+     */
+    public IgniteConfiguration setIgniteInstanceName(String instanceName) {
+        this.igniteInstanceName = instanceName;
 
         return this;
     }

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/core/src/main/java/org/apache/ignite/internal/GridDiagnostic.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/GridKernalContextImpl.java b/modules/core/src/main/java/org/apache/ignite/internal/GridKernalContextImpl.java
index d80d53c..60b368c 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/GridKernalContextImpl.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/GridKernalContextImpl.java
@@ -618,8 +618,8 @@ public class GridKernalContextImpl implements GridKernalContext, Externalizable
     }
 
     /** {@inheritDoc} */
-    @Override public String gridName() {
-        return cfg.getGridName();
+    @Override public String igniteInstanceName() {
+        return cfg.getIgniteInstanceName();
     }
 
     /** {@inheritDoc} */
@@ -885,7 +885,7 @@ public class GridKernalContextImpl implements GridKernalContext, Externalizable
     /** {@inheritDoc} */
     @Override public void printMemoryStats() {
         X.println(">>> ");
-        X.println(">>> Grid memory stats [grid=" + gridName() + ']');
+        X.println(">>> Grid memory stats [igniteInstanceName=" + igniteInstanceName() + ']');
 
         for (GridComponent comp : comps)
             comp.printMemoryStats();

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/core/src/main/java/org/apache/ignite/internal/GridKernalGatewayImpl.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/GridKernalGatewayImpl.java b/modules/core/src/main/java/org/apache/ignite/internal/GridKernalGatewayImpl.java
index 7cbf84a..f7982e2 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/GridKernalGatewayImpl.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/GridKernalGatewayImpl.java
@@ -54,7 +54,7 @@ public class GridKernalGatewayImpl implements GridKernalGateway, Serializable {
 
     /** */
     @GridToStringExclude
-    private final String gridName;
+    private final String igniteInstanceName;
 
     /**
      * User stack trace.
@@ -64,10 +64,10 @@ public class GridKernalGatewayImpl implements GridKernalGateway, Serializable {
     private String stackTrace;
 
     /**
-     * @param gridName Grid name.
+     * @param igniteInstanceName Ignite instance name.
      */
-    public GridKernalGatewayImpl(String gridName) {
-        this.gridName = gridName;
+    public GridKernalGatewayImpl(String igniteInstanceName) {
+        this.igniteInstanceName = igniteInstanceName;
     }
 
     /** {@inheritDoc} */
@@ -89,7 +89,7 @@ public class GridKernalGatewayImpl implements GridKernalGateway, Serializable {
             if (state == GridKernalState.DISCONNECTED) {
                 assert reconnectFut != null;
 
-                throw new IgniteClientDisconnectedException(reconnectFut, "Client node disconnected: " + gridName);
+                throw new IgniteClientDisconnectedException(reconnectFut, "Client node disconnected: " + igniteInstanceName);
             }
 
             throw illegalState();
@@ -104,7 +104,7 @@ public class GridKernalGatewayImpl implements GridKernalGateway, Serializable {
         rwLock.readLock().lock();
 
         if (state.get() == GridKernalState.DISCONNECTED)
-            throw new IgniteClientDisconnectedException(reconnectFut, "Client node disconnected: " + gridName);
+            throw new IgniteClientDisconnectedException(reconnectFut, "Client node disconnected: " + igniteInstanceName);
     }
 
     /** {@inheritDoc} */
@@ -193,7 +193,7 @@ public class GridKernalGatewayImpl implements GridKernalGateway, Serializable {
      */
     private IllegalStateException illegalState() {
         return new IllegalStateException("Grid is in invalid state to perform this operation. " +
-            "It either not started yet or has already being or have stopped [gridName=" + gridName +
+            "It either not started yet or has already being or have stopped [igniteInstanceName=" + igniteInstanceName +
             ", state=" + state + ']');
     }
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/core/src/main/java/org/apache/ignite/internal/GridLoggerProxy.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/IgniteKernal.java b/modules/core/src/main/java/org/apache/ignite/internal/IgniteKernal.java
index f6e47b7..2a6706e 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/IgniteKernal.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/IgniteKernal.java
@@ -207,7 +207,7 @@ import static org.apache.ignite.internal.IgniteNodeAttributes.ATTR_CLIENT_MODE;
 import static org.apache.ignite.internal.IgniteNodeAttributes.ATTR_CONSISTENCY_CHECK_SKIPPED;
 import static org.apache.ignite.internal.IgniteNodeAttributes.ATTR_DAEMON;
 import static org.apache.ignite.internal.IgniteNodeAttributes.ATTR_DEPLOYMENT_MODE;
-import static org.apache.ignite.internal.IgniteNodeAttributes.ATTR_GRID_NAME;
+import static org.apache.ignite.internal.IgniteNodeAttributes.ATTR_IGNITE_INSTANCE_NAME;
 import static org.apache.ignite.internal.IgniteNodeAttributes.ATTR_IPS;
 import static org.apache.ignite.internal.IgniteNodeAttributes.ATTR_JIT_NAME;
 import static org.apache.ignite.internal.IgniteNodeAttributes.ATTR_JMX_PORT;
@@ -269,7 +269,7 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
     private GridLoggerProxy log;
 
     /** */
-    private String gridName;
+    private String igniteInstanceName;
 
     /** */
     @GridToStringExclude
@@ -417,7 +417,7 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
 
     /** {@inheritDoc} */
     @Override public String name() {
-        return gridName;
+        return igniteInstanceName;
     }
 
     /** {@inheritDoc} */
@@ -540,7 +540,7 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
 
     /** {@inheritDoc} */
     @Override public String getInstanceName() {
-        return gridName;
+        return igniteInstanceName;
     }
 
     /** {@inheritDoc} */
@@ -666,7 +666,7 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
         // Catch generic throwable to secure against user assertions.
         catch (Throwable e) {
             U.error(log, "Failed to notify lifecycle bean (safely ignored) [evt=" + evt +
-                (gridName == null ? "" : ", gridName=" + gridName) + ']', e);
+                (igniteInstanceName == null ? "" : ", igniteInstanceName=" + igniteInstanceName) + ']', e);
 
             if (e instanceof Error)
                 throw (Error)e;
@@ -711,7 +711,7 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
     )
         throws IgniteCheckedException
     {
-        gw.compareAndSet(null, new GridKernalGatewayImpl(cfg.getGridName()));
+        gw.compareAndSet(null, new GridKernalGatewayImpl(cfg.getIgniteInstanceName()));
 
         GridKernalGateway gw = this.gw.get();
 
@@ -751,12 +751,12 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
         // Make sure we got proper configuration.
         validateCommon(cfg);
 
-        gridName = cfg.getGridName();
+        igniteInstanceName = cfg.getIgniteInstanceName();
 
         this.cfg = cfg;
 
         log = (GridLoggerProxy)cfg.getGridLogger().getLogger(
-            getClass().getName() + (gridName != null ? '%' + gridName : ""));
+            getClass().getName() + (igniteInstanceName != null ? '%' + igniteInstanceName : ""));
 
         RuntimeMXBean rtBean = ManagementFactory.getRuntimeMXBean();
 
@@ -776,7 +776,7 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
         ackRebalanceConfiguration();
 
         // Run background network diagnostics.
-        GridDiagnostic.runBackgroundCheck(gridName, execSvc, log);
+        GridDiagnostic.runBackgroundCheck(igniteInstanceName, execSvc, log);
 
         // Ack 3-rd party licenses location.
         if (log.isInfoEnabled() && cfg.getIgniteHome() != null)
@@ -1195,7 +1195,7 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
 
         ctx.performance().add("Disable assertions (remove '-ea' from JVM options)", !U.assertionsEnabled());
 
-        ctx.performance().logSuggestions(log, gridName);
+        ctx.performance().logSuggestions(log, igniteInstanceName);
 
         U.quietAndInfo(log, "To start Console Management & Monitoring run ignitevisorcmd.{sh|bat}");
 
@@ -1428,7 +1428,7 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
         }
 
         add(ATTR_USER_NAME, System.getProperty("user.name"));
-        add(ATTR_GRID_NAME, gridName);
+        add(ATTR_IGNITE_INSTANCE_NAME, igniteInstanceName);
 
         add(ATTR_PEER_CLASSLOADING, cfg.isPeerClassLoadingEnabled());
         add(ATTR_DEPLOYMENT_MODE, cfg.getDeploymentMode());
@@ -1524,7 +1524,7 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
         try {
             kernalMBean = U.registerMBean(
                 cfg.getMBeanServer(),
-                cfg.getGridName(),
+                cfg.getIgniteInstanceName(),
                 "Kernal",
                 getClass().getSimpleName(),
                 this,
@@ -1547,7 +1547,7 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
         try {
             locNodeMBean = U.registerMBean(
                 cfg.getMBeanServer(),
-                cfg.getGridName(),
+                cfg.getIgniteInstanceName(),
                 "Kernal",
                 mbean.getClass().getSimpleName(),
                 mbean,
@@ -1601,7 +1601,7 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
         try {
             ObjectName res = U.registerMBean(
                 cfg.getMBeanServer(),
-                cfg.getGridName(),
+                cfg.getIgniteInstanceName(),
                 "Thread Pools",
                 name,
                 new ThreadPoolMXBeanAdapter(exec),
@@ -1629,7 +1629,7 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
             try {
                 stripedExecSvcMBean = U.registerMBean(
                     cfg.getMBeanServer(),
-                    cfg.getGridName(),
+                    cfg.getIgniteInstanceName(),
                     "Thread Pools",
                     name,
                     new StripedExecutorMXBeanAdapter(stripedExecSvc),
@@ -1854,7 +1854,7 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
         if (log.isQuiet()) {
             U.quiet(false, "");
             U.quiet(false, "Ignite node started OK (id=" + U.id8(locNode.id()) +
-                (F.isEmpty(gridName) ? "" : ", grid=" + gridName) + ')');
+                (F.isEmpty(igniteInstanceName) ? "" : ", instance name=" + igniteInstanceName) + ')');
         }
 
         if (log.isInfoEnabled()) {
@@ -1878,7 +1878,7 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
                     ">>> CPU(s): " + locNode.metrics().getTotalCpus() + NL +
                     ">>> Heap: " + U.heapSize(locNode, 2) + "GB" + NL +
                     ">>> VM name: " + rtBean.getName() + NL +
-                    (gridName == null ? "" : ">>> Grid name: " + gridName + NL) +
+                    (igniteInstanceName == null ? "" : ">>> Ignite instance name: " + igniteInstanceName + NL) +
                     ">>> Local node [" +
                     "ID=" + locNode.id().toString().toUpperCase() +
                     ", order=" + locNode.order() + ", clientMode=" + ctx.clientNode() +
@@ -2001,7 +2001,7 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
      * @param cancel Whether or not to cancel running jobs.
      */
     private void stop0(boolean cancel) {
-        gw.compareAndSet(null, new GridKernalGatewayImpl(gridName));
+        gw.compareAndSet(null, new GridKernalGatewayImpl(igniteInstanceName));
 
         GridKernalGateway gw = this.gw.get();
 
@@ -2081,7 +2081,8 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
                 ctx.cluster().get().clearNodeMap();
 
                 if (log.isDebugEnabled())
-                    log.debug("Grid " + (gridName == null ? "" : '\'' + gridName + "' ") + "is stopping.");
+                    log.debug("Grid " + (igniteInstanceName == null ? "" : '\'' + igniteInstanceName + "' ") +
+                        "is stopping.");
             }
             finally {
                 gw.writeUnlock();
@@ -2151,7 +2152,7 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
 
             // Ack stop.
             if (log.isQuiet()) {
-                String nodeName = gridName == null ? "" : "name=" + gridName + ", ";
+                String nodeName = igniteInstanceName == null ? "" : "name=" + igniteInstanceName + ", ";
 
                 if (!errOnStop)
                     U.quiet(false, "Ignite node stopped OK [" + nodeName + "uptime=" +
@@ -2172,7 +2173,7 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
                         ">>> " + dash + NL +
                         ">>> " + ack + NL +
                         ">>> " + dash + NL +
-                        (gridName == null ? "" : ">>> Grid name: " + gridName + NL) +
+                        (igniteInstanceName == null ? "" : ">>> Ignite instance name: " + igniteInstanceName + NL) +
                         ">>> Grid uptime: " + X.timeSpan2HMSM(U.currentTimeMillis() - startTime) +
                         NL +
                         NL);
@@ -2186,7 +2187,7 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
                     log.info(NL + NL +
                         ">>> " + ack + NL +
                         ">>> " + dash + NL +
-                        (gridName == null ? "" : ">>> Grid name: " + gridName + NL) +
+                        (igniteInstanceName == null ? "" : ">>> Ignite instance name: " + igniteInstanceName + NL) +
                         ">>> Grid uptime: " + X.timeSpan2HMSM(U.currentTimeMillis() - startTime) +
                         NL +
                         ">>> See log above for detailed error message." + NL +
@@ -3176,7 +3177,7 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
 
     /** {@inheritDoc} */
     @Override public void close() throws IgniteException {
-        Ignition.stop(gridName, true);
+        Ignition.stop(igniteInstanceName, true);
     }
 
     /** {@inheritDoc} */
@@ -3556,12 +3557,12 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
 
     /** {@inheritDoc} */
     @Override public void readExternal(ObjectInput in) throws IOException, ClassNotFoundException {
-        gridName = U.readString(in);
+        igniteInstanceName = U.readString(in);
     }
 
     /** {@inheritDoc} */
     @Override public void writeExternal(ObjectOutput out) throws IOException {
-        U.writeString(out, gridName);
+        U.writeString(out, igniteInstanceName);
     }
 
     /**
@@ -3601,7 +3602,7 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
                 UUID routerId = locNode instanceof TcpDiscoveryNode ? ((TcpDiscoveryNode)locNode).clientRouterNodeId() : null;
 
                 U.warn(log, "Dumping debug info for node [id=" + locNode.id() +
-                    ", name=" + ctx.gridName() +
+                    ", name=" + ctx.igniteInstanceName() +
                     ", order=" + locNode.order() +
                     ", topVer=" + discoMrg.topologyVersion() +
                     ", client=" + client +
@@ -3610,7 +3611,8 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
                 ctx.cache().context().exchange().dumpDebugInfo();
             }
             else
-                U.warn(log, "Dumping debug info for node, context is not initialized [name=" + gridName + ']');
+                U.warn(log, "Dumping debug info for node, context is not initialized [name=" + igniteInstanceName +
+                    ']');
         }
         catch (Exception e) {
             U.error(log, "Failed to dump debug info for node: " + e, e);

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/core/src/main/java/org/apache/ignite/internal/IgniteNodeAttributes.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/IgniteNodeAttributes.java b/modules/core/src/main/java/org/apache/ignite/internal/IgniteNodeAttributes.java
index e7c984f..8294026 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/IgniteNodeAttributes.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/IgniteNodeAttributes.java
@@ -53,7 +53,15 @@ public final class IgniteNodeAttributes {
     public static final String ATTR_USER_NAME = ATTR_PREFIX + ".user.name";
 
     /** Internal attribute name constant. */
-    public static final String ATTR_GRID_NAME = ATTR_PREFIX + ".ignite.name";
+    public static final String ATTR_IGNITE_INSTANCE_NAME = ATTR_PREFIX + ".ignite.name";
+
+    /**
+     * Internal attribute name constant.
+     *
+     * @deprecated Use {@link #ATTR_IGNITE_INSTANCE_NAME}.
+     */
+    @Deprecated
+    public static final String ATTR_GRID_NAME = ATTR_IGNITE_INSTANCE_NAME;
 
     /** Deployment mode. */
     public static final String ATTR_DEPLOYMENT_MODE = ATTR_PREFIX + ".ignite.dep.mode";

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/core/src/main/java/org/apache/ignite/internal/IgnitionEx.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/IgnitionEx.java b/modules/core/src/main/java/org/apache/ignite/internal/IgnitionEx.java
index 9fe2dba..2d35cdb 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/IgnitionEx.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/IgnitionEx.java
@@ -147,7 +147,7 @@ public class IgnitionEx {
     /** Default configuration path relative to Ignite home. */
     public static final String DFLT_CFG = "config/default-config.xml";
 
-    /** Map of named grids. */
+    /** Map of named Ignite instances. */
     private static final ConcurrentMap<Object, IgniteNamedInstance> grids = new ConcurrentHashMap8<>();
 
     /** Map of grid states ever started in this JVM. */
@@ -257,11 +257,11 @@ public class IgnitionEx {
     }
 
     /**
-     * Gets states of named grid. If name is {@code null}, then state of
-     * default no-name grid is returned.
+     * Gets states of named Ignite instance. If name is {@code null}, then state of
+     * default no-name Ignite instance is returned.
      *
-     * @param name Grid name. If name is {@code null}, then state of
-     *      default no-name grid is returned.
+     * @param name Ignite instance name. If name is {@code null}, then state of
+     *      default no-name Ignite instance is returned.
      * @return Grid state.
      */
     public static IgniteState state(@Nullable String name) {
@@ -292,14 +292,14 @@ public class IgnitionEx {
     }
 
     /**
-     * Stops named grid. If {@code cancel} flag is set to {@code true} then
+     * Stops named Ignite instance. If {@code cancel} flag is set to {@code true} then
      * all jobs currently executing on local node will be interrupted. If
-     * grid name is {@code null}, then default no-name grid will be stopped.
-     * If wait parameter is set to {@code true} then grid will wait for all
+     * Ignite instance name is {@code null}, then default no-name Ignite instance will be stopped.
+     * If wait parameter is set to {@code true} then Ignite instance will wait for all
      * tasks to be finished.
      *
-     * @param name Grid name. If {@code null}, then default no-name grid will
-     *      be stopped.
+     * @param name Ignite instance name. If {@code null}, then default no-name
+     *      Ignite instance will be stopped.
      * @param cancel If {@code true} then all jobs currently will be cancelled
      *      by calling {@link ComputeJob#cancel()} method. Note that just like with
      *      {@link Thread#interrupt()}, it is up to the actual job to exit from
@@ -307,7 +307,7 @@ public class IgnitionEx {
      *      canceled. In either case, grid node will wait for completion of all
      *      jobs running on it before stopping.
      * @param stopNotStarted If {@code true} and node start did not finish then interrupts starting thread.
-     * @return {@code true} if named grid instance was indeed found and stopped,
+     * @return {@code true} if named Ignite instance was indeed found and stopped,
      *      {@code false} otherwise (the instance with given {@code name} was
      *      not found).
      */
@@ -343,7 +343,7 @@ public class IgnitionEx {
         }
 
         // We don't have log at this point...
-        U.warn(null, "Ignoring stopping grid instance that was already stopped or never started: " + name);
+        U.warn(null, "Ignoring stopping Ignite instance that was already stopped or never started: " + name);
 
         return false;
     }
@@ -626,24 +626,25 @@ public class IgnitionEx {
      * the Grid configuration bean is ignored.
      *
      * @param springCfgPath Spring XML configuration file path or URL.
-     * @param gridName Grid name that will override default.
+     * @param igniteInstanceName Ignite instance name that will override default.
      * @return Started grid. If Spring configuration contains multiple grid instances,
      *      then the 1st found instance is returned.
      * @throws IgniteCheckedException If grid could not be started or configuration
      *      read. This exception will be thrown also if grid with given name has already
      *      been started or Spring XML configuration file is invalid.
      */
-    public static Ignite start(@Nullable String springCfgPath, @Nullable String gridName) throws IgniteCheckedException {
+    public static Ignite start(@Nullable String springCfgPath, @Nullable String igniteInstanceName)
+        throws IgniteCheckedException {
         if (springCfgPath == null) {
             IgniteConfiguration cfg = new IgniteConfiguration();
 
-            if (cfg.getGridName() == null && !F.isEmpty(gridName))
-                cfg.setGridName(gridName);
+            if (cfg.getIgniteInstanceName() == null && !F.isEmpty(igniteInstanceName))
+                cfg.setIgniteInstanceName(igniteInstanceName);
 
             return start(cfg);
         }
         else
-            return start(springCfgPath, gridName, null, null);
+            return start(springCfgPath, igniteInstanceName, null, null);
     }
 
     /**
@@ -757,7 +758,7 @@ public class IgnitionEx {
      * the Grid configuration bean is ignored.
      *
      * @param springCfgPath Spring XML configuration file path or URL. This cannot be {@code null}.
-     * @param gridName Grid name that will override default.
+     * @param igniteInstanceName Ignite instance name that will override default.
      * @param springCtx Optional Spring application context, possibly {@code null}.
      * @param ldr Optional class loader that will be used by default.
      *      Spring bean definitions for bean injection are taken from this context.
@@ -769,11 +770,11 @@ public class IgnitionEx {
      *      read. This exception will be thrown also if grid with given name has already
      *      been started or Spring XML configuration file is invalid.
      */
-    public static Ignite start(String springCfgPath, @Nullable String gridName,
+    public static Ignite start(String springCfgPath, @Nullable String igniteInstanceName,
         @Nullable GridSpringResourceContext springCtx, @Nullable ClassLoader ldr) throws IgniteCheckedException {
         URL url = U.resolveSpringUrl(springCfgPath);
 
-        return start(url, gridName, springCtx, ldr);
+        return start(url, igniteInstanceName, springCtx, ldr);
     }
 
     /**
@@ -827,7 +828,7 @@ public class IgnitionEx {
      * the Grid configuration bean is ignored.
      *
      * @param springCfgUrl Spring XML configuration file URL. This cannot be {@code null}.
-     * @param gridName Grid name that will override default.
+     * @param igniteInstanceName Ignite instance name that will override default.
      * @param springCtx Optional Spring application context, possibly {@code null}.
      * @param ldr Optional class loader that will be used by default.
      *      Spring bean definitions for bean injection are taken from this context.
@@ -839,7 +840,7 @@ public class IgnitionEx {
      *      read. This exception will be thrown also if grid with given name has already
      *      been started or Spring XML configuration file is invalid.
      */
-    public static Ignite start(URL springCfgUrl, @Nullable String gridName,
+    public static Ignite start(URL springCfgUrl, @Nullable String igniteInstanceName,
         @Nullable GridSpringResourceContext springCtx, @Nullable ClassLoader ldr) throws IgniteCheckedException {
         A.notNull(springCfgUrl, "springCfgUrl");
 
@@ -874,7 +875,7 @@ public class IgnitionEx {
                 U.removeJavaNoOpLogger(savedHnds);
         }
 
-        return startConfigurations(cfgMap, springCfgUrl, gridName, springCtx, ldr);
+        return startConfigurations(cfgMap, springCfgUrl, igniteInstanceName, springCtx, ldr);
     }
 
     /**
@@ -907,7 +908,7 @@ public class IgnitionEx {
      * the Grid configuration bean is ignored.
      *
      * @param springCfgStream Input stream containing Spring XML configuration. This cannot be {@code null}.
-     * @param gridName Grid name that will override default.
+     * @param igniteInstanceName Ignite instance name that will override default.
      * @param springCtx Optional Spring application context, possibly {@code null}.
      * @param ldr Optional class loader that will be used by default.
      *      Spring bean definitions for bean injection are taken from this context.
@@ -919,7 +920,7 @@ public class IgnitionEx {
      *      read. This exception will be thrown also if grid with given name has already
      *      been started or Spring XML configuration file is invalid.
      */
-    public static Ignite start(InputStream springCfgStream, @Nullable String gridName,
+    public static Ignite start(InputStream springCfgStream, @Nullable String igniteInstanceName,
         @Nullable GridSpringResourceContext springCtx, @Nullable ClassLoader ldr) throws IgniteCheckedException {
         A.notNull(springCfgStream, "springCfgUrl");
 
@@ -954,7 +955,7 @@ public class IgnitionEx {
                 U.removeJavaNoOpLogger(savedHnds);
         }
 
-        return startConfigurations(cfgMap, null, gridName, springCtx, ldr);
+        return startConfigurations(cfgMap, null, igniteInstanceName, springCtx, ldr);
     }
 
     /**
@@ -962,7 +963,7 @@ public class IgnitionEx {
      *
      * @param cfgMap Configuration map.
      * @param springCfgUrl Spring XML configuration file URL.
-     * @param gridName Grid name that will override default.
+     * @param igniteInstanceName Ignite instance name that will override default.
      * @param springCtx Optional Spring application context.
      * @param ldr Optional class loader that will be used by default.
      * @return Started grid.
@@ -971,7 +972,7 @@ public class IgnitionEx {
     private static Ignite startConfigurations(
         IgniteBiTuple<Collection<IgniteConfiguration>, ? extends GridSpringResourceContext> cfgMap,
         URL springCfgUrl,
-        @Nullable String gridName,
+        @Nullable String igniteInstanceName,
         @Nullable GridSpringResourceContext springCtx,
         @Nullable ClassLoader ldr)
         throws IgniteCheckedException {
@@ -981,8 +982,8 @@ public class IgnitionEx {
             for (IgniteConfiguration cfg : cfgMap.get1()) {
                 assert cfg != null;
 
-                if (cfg.getGridName() == null && !F.isEmpty(gridName))
-                    cfg.setGridName(gridName);
+                if (cfg.getIgniteInstanceName() == null && !F.isEmpty(igniteInstanceName))
+                    cfg.setIgniteInstanceName(igniteInstanceName);
 
                 if (ldr != null && cfg.getClassLoader() == null)
                     cfg.setClassLoader(ldr);
@@ -1030,10 +1031,10 @@ public class IgnitionEx {
     private static T2<IgniteNamedInstance, Boolean> start0(GridStartContext startCtx, boolean failIfStarted ) throws IgniteCheckedException {
         assert startCtx != null;
 
-        String name = startCtx.config().getGridName();
+        String name = startCtx.config().getIgniteInstanceName();
 
         if (name != null && name.isEmpty())
-            throw new IgniteCheckedException("Non default grid instances cannot have empty string name.");
+            throw new IgniteCheckedException("Non default Ignite instances cannot have empty string name.");
 
         IgniteNamedInstance grid = new IgniteNamedInstance(name);
 
@@ -1055,7 +1056,8 @@ public class IgnitionEx {
                 if (name == null)
                     throw new IgniteCheckedException("Default Ignite instance has already been started.");
                 else
-                    throw new IgniteCheckedException("Ignite instance with this name has already been started: " + name);
+                    throw new IgniteCheckedException("Ignite instance with this name has already been started: " +
+                        name);
             }
             else
                 return new T2<>(old, false);
@@ -1319,9 +1321,9 @@ public class IgnitionEx {
         if (U.isCurrentIgniteNameSet(name))
             return gridx(name);
         else if (Thread.currentThread() instanceof IgniteThread)
-            return gridx(((IgniteThread)Thread.currentThread()).getGridName());
+            return gridx(((IgniteThread)Thread.currentThread()).getIgniteInstanceName());
         else
-            throw new IllegalArgumentException("Ignite grid name thread local must be set or" +
+            throw new IllegalArgumentException("Ignite instance name thread local must be set or" +
                 " this method should be accessed under " + IgniteThread.class.getName());
     }
 
@@ -1374,17 +1376,17 @@ public class IgnitionEx {
     }
 
     /**
-     * @param gridName Grid instance name.
+     * @param igniteInstanceName Ignite instance name.
      * @param state Factory state.
      */
-    private static void notifyStateChange(@Nullable String gridName, IgniteState state) {
-        if (gridName != null)
-            gridStates.put(gridName, state);
+    private static void notifyStateChange(@Nullable String igniteInstanceName, IgniteState state) {
+        if (igniteInstanceName != null)
+            gridStates.put(igniteInstanceName, state);
         else
             dfltGridState = state;
 
         for (IgnitionListener lsnr : lsnrs)
-            lsnr.onStateChange(gridName, state);
+            lsnr.onStateChange(igniteInstanceName, state);
     }
 
     /**
@@ -1681,7 +1683,7 @@ public class IgnitionEx {
 
             execSvc = new IgniteThreadPoolExecutor(
                 "pub",
-                cfg.getGridName(),
+                cfg.getIgniteInstanceName(),
                 cfg.getPublicThreadPoolSize(),
                 cfg.getPublicThreadPoolSize(),
                 DFLT_THREAD_KEEP_ALIVE_TIME,
@@ -1693,7 +1695,7 @@ public class IgnitionEx {
 
             sysExecSvc = new IgniteThreadPoolExecutor(
                 "sys",
-                cfg.getGridName(),
+                cfg.getIgniteInstanceName(),
                 cfg.getSystemThreadPoolSize(),
                 cfg.getSystemThreadPoolSize(),
                 DFLT_THREAD_KEEP_ALIVE_TIME,
@@ -1702,7 +1704,7 @@ public class IgnitionEx {
             sysExecSvc.allowCoreThreadTimeOut(true);
 
             if (cfg.getStripedPoolSize() > 0)
-                stripedExecSvc = new StripedExecutor(cfg.getStripedPoolSize(), cfg.getGridName(), "sys", log);
+                stripedExecSvc = new StripedExecutor(cfg.getStripedPoolSize(), cfg.getIgniteInstanceName(), "sys", log);
 
             // Note that since we use 'LinkedBlockingQueue', number of
             // maximum threads has no effect.
@@ -1712,7 +1714,7 @@ public class IgnitionEx {
 
             mgmtExecSvc = new IgniteThreadPoolExecutor(
                 "mgmt",
-                cfg.getGridName(),
+                cfg.getIgniteInstanceName(),
                 cfg.getManagementThreadPoolSize(),
                 cfg.getManagementThreadPoolSize(),
                 DFLT_THREAD_KEEP_ALIVE_TIME,
@@ -1727,7 +1729,7 @@ public class IgnitionEx {
             validateThreadPoolSize(cfg.getPeerClassLoadingThreadPoolSize(), "peer class loading");
             p2pExecSvc = new IgniteThreadPoolExecutor(
                 "p2p",
-                cfg.getGridName(),
+                cfg.getIgniteInstanceName(),
                 cfg.getPeerClassLoadingThreadPoolSize(),
                 cfg.getPeerClassLoadingThreadPoolSize(),
                 DFLT_THREAD_KEEP_ALIVE_TIME,
@@ -1738,7 +1740,7 @@ public class IgnitionEx {
             // Note that we do not pre-start threads here as this pool may not be needed.
             dataStreamerExecSvc = new IgniteThreadPoolExecutor(
                 "data-streamer",
-                cfg.getGridName(),
+                cfg.getIgniteInstanceName(),
                 cfg.getDataStreamerThreadPoolSize(),
                 cfg.getDataStreamerThreadPoolSize(),
                 DFLT_THREAD_KEEP_ALIVE_TIME,
@@ -1754,7 +1756,7 @@ public class IgnitionEx {
                 cfg.getIgfsThreadPoolSize(),
                 DFLT_THREAD_KEEP_ALIVE_TIME,
                 new LinkedBlockingQueue<Runnable>(),
-                new IgfsThreadFactory(cfg.getGridName(), "igfs"),
+                new IgfsThreadFactory(cfg.getIgniteInstanceName(), "igfs"),
                 null /* Abort policy will be used. */);
 
             igfsExecSvc.allowCoreThreadTimeOut(true);
@@ -1764,7 +1766,7 @@ public class IgnitionEx {
 
             callbackExecSvc = new IgniteStripedThreadPoolExecutor(
                 cfg.getAsyncCallbackPoolSize(),
-                cfg.getGridName(),
+                cfg.getIgniteInstanceName(),
                 "callback");
 
             if (myCfg.getConnectorConfiguration() != null) {
@@ -1772,7 +1774,7 @@ public class IgnitionEx {
 
                 restExecSvc = new IgniteThreadPoolExecutor(
                     "rest",
-                    myCfg.getGridName(),
+                    myCfg.getIgniteInstanceName(),
                     myCfg.getConnectorConfiguration().getThreadPoolSize(),
                     myCfg.getConnectorConfiguration().getThreadPoolSize(),
                     DFLT_THREAD_KEEP_ALIVE_TIME,
@@ -1786,7 +1788,7 @@ public class IgnitionEx {
 
             utilityCacheExecSvc = new IgniteThreadPoolExecutor(
                 "utility",
-                cfg.getGridName(),
+                cfg.getIgniteInstanceName(),
                 myCfg.getUtilityCacheThreadPoolSize(),
                 myCfg.getUtilityCacheThreadPoolSize(),
                 myCfg.getUtilityCacheKeepAliveTime(),
@@ -1796,7 +1798,7 @@ public class IgnitionEx {
 
             affExecSvc = new IgniteThreadPoolExecutor(
                 "aff",
-                cfg.getGridName(),
+                cfg.getIgniteInstanceName(),
                 1,
                 1,
                 DFLT_THREAD_KEEP_ALIVE_TIME,
@@ -1809,7 +1811,7 @@ public class IgnitionEx {
 
                 idxExecSvc = new IgniteThreadPoolExecutor(
                     "idx",
-                    cfg.getGridName(),
+                    cfg.getIgniteInstanceName(),
                     cpus,
                     cpus * 2,
                     3000L,
@@ -1821,7 +1823,7 @@ public class IgnitionEx {
 
             qryExecSvc = new IgniteThreadPoolExecutor(
                 "query",
-                cfg.getGridName(),
+                cfg.getIgniteInstanceName(),
                 cfg.getQueryThreadPoolSize(),
                 cfg.getQueryThreadPoolSize(),
                 DFLT_THREAD_KEEP_ALIVE_TIME,
@@ -1956,7 +1958,7 @@ public class IgnitionEx {
             // Ensure invariant.
             // It's a bit dirty - but this is a result of late refactoring
             // and I don't want to reshuffle a lot of code.
-            assert F.eq(name, cfg.getGridName());
+            assert F.eq(name, cfg.getIgniteInstanceName());
 
             UUID nodeId = cfg.getNodeId() != null ? cfg.getNodeId() : UUID.randomUUID();
 
@@ -2063,7 +2065,7 @@ public class IgnitionEx {
                     marsh = new BinaryMarshaller();
             }
 
-            MarshallerUtils.setNodeName(marsh, cfg.getGridName());
+            MarshallerUtils.setNodeName(marsh, cfg.getIgniteInstanceName());
 
             myCfg.setMarshaller(marsh);
 
@@ -2373,7 +2375,7 @@ public class IgnitionEx {
             // Double check.
             if (grid0 == null) {
                 if (log != null)
-                    U.warn(log, "Attempting to stop an already stopped grid instance (ignore): " + name);
+                    U.warn(log, "Attempting to stop an already stopped Ignite instance (ignore): " + name);
 
                 return;
             }
@@ -2400,7 +2402,7 @@ public class IgnitionEx {
                 grid0.stop(cancel);
 
                 if (log.isDebugEnabled())
-                    log.debug("Grid instance stopped ok: " + name);
+                    log.debug("Ignite instance stopped ok: " + name);
             }
             catch (Throwable e) {
                 U.error(log, "Failed to properly stop grid instance due to undeclared exception.", e);
@@ -2546,7 +2548,7 @@ public class IgnitionEx {
 
                 assert data != null;
 
-                data.addGrid(name);
+                data.addIgniteInstance(name);
                 data.setCounter(data.getCounter() + 1);
             }
         }
@@ -2561,7 +2563,7 @@ public class IgnitionEx {
                 while (iter.hasNext()) {
                     Entry<MBeanServer, GridMBeanServerData> entry = iter.next();
 
-                    if (entry.getValue().containsGrid(name)) {
+                    if (entry.getValue().containsIgniteInstance(name)) {
                         GridMBeanServerData data = entry.getValue();
 
                         assert data != null;
@@ -2583,7 +2585,7 @@ public class IgnitionEx {
                         else {
                             // Decrement counter.
                             data.setCounter(data.getCounter() - 1);
-                            data.removeGrid(name);
+                            data.removeIgniteInstance(name);
                         }
                     }
                 }
@@ -2596,7 +2598,7 @@ public class IgnitionEx {
          */
         private static class GridMBeanServerData {
             /** Set of grid names for selected MBeanServer. */
-            private Collection<String> gridNames = new HashSet<>();
+            private Collection<String> igniteInstanceNames = new HashSet<>();
 
             /** */
             private ObjectName mbean;
@@ -2616,32 +2618,32 @@ public class IgnitionEx {
             }
 
             /**
-             * Add grid name.
+             * Add Ignite instance name.
              *
-             * @param gridName Grid name.
+             * @param igniteInstanceName Ignite instance name.
              */
-            public void addGrid(String gridName) {
-                gridNames.add(gridName);
+            public void addIgniteInstance(String igniteInstanceName) {
+                igniteInstanceNames.add(igniteInstanceName);
             }
 
             /**
-             * Remove grid name.
+             * Remove Ignite instance name.
              *
-             * @param gridName Grid name.
+             * @param igniteInstanceName Ignite instance name.
              */
-            public void removeGrid(String gridName) {
-                gridNames.remove(gridName);
+            public void removeIgniteInstance(String igniteInstanceName) {
+                igniteInstanceNames.remove(igniteInstanceName);
             }
 
             /**
              * Returns {@code true} if data contains the specified
-             * grid name.
+             * Ignite instance name.
              *
-             * @param gridName Grid name.
-             * @return {@code true} if data contains the specified grid name.
+             * @param igniteInstanceName Ignite instance name.
+             * @return {@code true} if data contains the specified Ignite instance name.
              */
-            public boolean containsGrid(String gridName) {
-                return gridNames.contains(gridName);
+            public boolean containsIgniteInstance(String igniteInstanceName) {
+                return igniteInstanceNames.contains(igniteInstanceName);
             }
 
             /**

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/core/src/main/java/org/apache/ignite/internal/binary/BinaryContext.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/binary/BinaryContext.java b/modules/core/src/main/java/org/apache/ignite/internal/binary/BinaryContext.java
index 2cd9105..3517b8c 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/binary/BinaryContext.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/binary/BinaryContext.java
@@ -268,7 +268,7 @@ public class BinaryContext {
         assert metaHnd != null;
         assert igniteCfg != null;
 
-        MarshallerUtils.setNodeName(optmMarsh, igniteCfg.getGridName());
+        MarshallerUtils.setNodeName(optmMarsh, igniteCfg.getIgniteInstanceName());
 
         this.metaHnd = metaHnd;
         this.igniteCfg = igniteCfg;

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/core/src/main/java/org/apache/ignite/internal/binary/BinaryReaderExImpl.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/binary/BinaryReaderExImpl.java b/modules/core/src/main/java/org/apache/ignite/internal/binary/BinaryReaderExImpl.java
index b38d0ff..f851b68 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/binary/BinaryReaderExImpl.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/binary/BinaryReaderExImpl.java
@@ -1697,7 +1697,7 @@ public class BinaryReaderExImpl implements BinaryReader, BinaryRawReaderEx, Bina
      * @throws BinaryObjectException If failed.
      */
     @Nullable Object deserialize() throws BinaryObjectException {
-        String newName = ctx.configuration().getGridName();
+        String newName = ctx.configuration().getIgniteInstanceName();
         String oldName = IgniteUtils.setCurrentIgniteName(newName);
 
         try {

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/core/src/main/java/org/apache/ignite/internal/binary/BinaryWriterExImpl.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/binary/BinaryWriterExImpl.java b/modules/core/src/main/java/org/apache/ignite/internal/binary/BinaryWriterExImpl.java
index ba4822f..b091001 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/binary/BinaryWriterExImpl.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/binary/BinaryWriterExImpl.java
@@ -141,7 +141,7 @@ public class BinaryWriterExImpl implements BinaryWriter, BinaryRawWriterEx, Obje
      * @throws org.apache.ignite.binary.BinaryObjectException In case of error.
      */
     void marshal(Object obj, boolean enableReplace) throws BinaryObjectException {
-        String newName = ctx.configuration().getGridName();
+        String newName = ctx.configuration().getIgniteInstanceName();
         String oldName = IgniteUtils.setCurrentIgniteName(newName);
 
         try {

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/core/src/main/java/org/apache/ignite/internal/client/impl/connection/GridClientConnectionManagerAdapter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/client/impl/connection/GridClientConnectionManagerAdapter.java b/modules/core/src/main/java/org/apache/ignite/internal/client/impl/connection/GridClientConnectionManagerAdapter.java
index f714e7a..e325897 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/client/impl/connection/GridClientConnectionManagerAdapter.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/client/impl/connection/GridClientConnectionManagerAdapter.java
@@ -204,7 +204,7 @@ public abstract class GridClientConnectionManagerAdapter implements GridClientCo
                     .socketReceiveBufferSize(0)
                     .socketSendBufferSize(0)
                     .idleTimeout(Long.MAX_VALUE)
-                    .gridName(routerClient ? "routerClient" : "gridClient")
+                    .igniteInstanceName(routerClient ? "routerClient" : "gridClient")
                     .serverName("tcp-client")
                     .daemon(cfg.isDaemon())
                     .build();
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/GridDiagnostic.java b/modules/core/src/main/java/org/apache/ignite/internal/GridDiagnostic.java
index 19c12cb..4a33b9d 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/GridDiagnostic.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/GridDiagnostic.java
@@ -43,18 +43,18 @@ final class GridDiagnostic {
     }
 
     /**
      * @param gridName Grid instance name. Can be {@code null}.
      * @param exec Executor service.
      * @param parentLog Parent logger.
      */
-    static void runBackgroundCheck(String gridName, Executor exec, IgniteLogger parentLog) {
+    static void runBackgroundCheck(String igniteInstanceName, Executor exec, IgniteLogger parentLog) {
         assert exec != null;
         assert parentLog != null;
 
         final IgniteLogger log = parentLog.getLogger(GridDiagnostic.class);
 
         try {
-            exec.execute(new GridWorker(gridName, "grid-diagnostic-1", log) {
+            exec.execute(new GridWorker(igniteInstanceName, "grid-diagnostic-1", log) {
                 @Override public void body() {
                     try {
                         InetAddress locHost = U.getLocalHost();
@@ -73,7 +73,7 @@ final class GridDiagnostic {
                 }
             });
 
-            exec.execute(new GridWorker(gridName, "grid-diagnostic-2", log) {
+            exec.execute(new GridWorker(igniteInstanceName, "grid-diagnostic-2", log) {
                 @Override public void body() {
                     try {
                         InetAddress locHost = U.getLocalHost();
@@ -92,7 +92,7 @@ final class GridDiagnostic {
                 }
             });
 
-            exec.execute(new GridWorker(gridName, "grid-diagnostic-4", log) {
+            exec.execute(new GridWorker(igniteInstanceName, "grid-diagnostic-4", log) {
                 @Override public void body() {
                     // Sufficiently tested OS.
                     if (!U.isSufficientlyTestedOs()) {
@@ -104,7 +104,7 @@ final class GridDiagnostic {
                 }
             });
 
-            exec.execute(new GridWorker(gridName, "grid-diagnostic-5", log) {
+            exec.execute(new GridWorker(igniteInstanceName, "grid-diagnostic-5", log) {
                 @Override public void body() {
                     // Fix for GG-1075.
                     if (F.isEmpty(U.allLocalMACs()))
@@ -114,7 +114,7 @@ final class GridDiagnostic {
                 }
             });
 
-            exec.execute(new GridWorker(gridName, "grid-diagnostic-6", log) {
+            exec.execute(new GridWorker(igniteInstanceName, "grid-diagnostic-6", log) {
                 @Override public void body() {
                     if (System.getProperty("com.sun.management.jmxremote") != null) {
                         String portStr = System.getProperty("com.sun.management.jmxremote.port");
@@ -138,7 +138,7 @@ final class GridDiagnostic {
 
             final long HALF_GB = 512/*MB*/ * 1024 * 1024;
 
-            exec.execute(new GridWorker(gridName, "grid-diagnostic-7", log) {
+            exec.execute(new GridWorker(igniteInstanceName, "grid-diagnostic-7", log) {
                 @Override public void body() {
                     long initBytes = ManagementFactory.getMemoryMXBean().getHeapMemoryUsage().getInit();
                     long initMb = initBytes / 1024 / 1024;

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/core/src/main/java/org/apache/ignite/internal/GridKernalContext.java
----------------------------------------------------------------------
@@ -43,18 +43,18 @@ final class GridDiagnostic {
 
     /**
-     * @param gridName Grid instance name. Can be {@code null}.
+     * @param igniteInstanceName Grid instance name. Can be {@code null}.
      * @param exec Executor service.
      * @param parentLog Parent logger.
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/GridKernalContext.java b/modules/core/src/main/java/org/apache/ignite/internal/GridKernalContext.java
index 937a6f9..0738df3 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/GridKernalContext.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/GridKernalContext.java
@@ -95,11 +95,11 @@ public interface GridKernalContext extends Iterable<GridComponent> {
     public UUID localNodeId();
 
     /**
      * Gets grid name.
      *
-     * @return Grid name.
+     * @return Ignite instance name.
      */
-    public String gridName();
+    public String igniteInstanceName();
 
     /**
      * Gets logger for given category.

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/core/src/main/java/org/apache/ignite/internal/GridKernalContextImpl.java
----------------------------------------------------------------------
@@ -95,11 +95,11 @@ public interface GridKernalContext extends Iterable<GridComponent> {
 
     /**
-     * Gets grid name.
+     * Gets Ignite instance name.
      *
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/GridLoggerProxy.java b/modules/core/src/main/java/org/apache/ignite/internal/GridLoggerProxy.java
index b26921b..9f5daae 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/GridLoggerProxy.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/GridLoggerProxy.java
@@ -33,6 +33,7 @@ import org.apache.ignite.lifecycle.LifecycleAware;
 import org.jetbrains.annotations.Nullable;
 
 import static org.apache.ignite.IgniteSystemProperties.IGNITE_LOG_GRID_NAME;
+import static org.apache.ignite.IgniteSystemProperties.IGNITE_LOG_INSTANCE_NAME;
 
 /**
  *
@@ -52,7 +53,7 @@ public class GridLoggerProxy implements IgniteLogger, LifecycleAware, Externaliz
     private IgniteLogger impl;
 
     /** */
-    private String gridName;
+    private String igniteInstanceName;
 
     /** */
     private String id8;
@@ -61,8 +62,9 @@ public class GridLoggerProxy implements IgniteLogger, LifecycleAware, Externaliz
     @GridToStringExclude
     private Object ctgr;
 
-    /** Whether or not to log grid name. */
-    private static final boolean logGridName = System.getProperty(IGNITE_LOG_GRID_NAME) != null;
+    /** Whether or not to log Ignite instance name. */
+    private static final boolean logIgniteInstanceName = System.getProperty(IGNITE_LOG_INSTANCE_NAME) != null ||
+        System.getProperty(IGNITE_LOG_GRID_NAME) != null;
 
     /**
      * No-arg constructor is required by externalization.
@@ -75,16 +77,16 @@ public class GridLoggerProxy implements IgniteLogger, LifecycleAware, Externaliz
      *
      * @param impl Logger implementation to proxy to.
      * @param ctgr Optional logger category.
      * @param gridName Grid name (can be {@code null} for default grid).
      * @param id8 Node ID.
      */
     @SuppressWarnings({"IfMayBeConditional", "SimplifiableIfStatement"})
-    public GridLoggerProxy(IgniteLogger impl, @Nullable Object ctgr, @Nullable String gridName, String id8) {
+    public GridLoggerProxy(IgniteLogger impl, @Nullable Object ctgr, @Nullable String igniteInstanceName, String id8) {
         assert impl != null;
 
         this.impl = impl;
         this.ctgr = ctgr;
-        this.gridName = gridName;
+        this.igniteInstanceName = igniteInstanceName;
         this.id8 = id8;
     }
 
@@ -103,7 +105,7 @@ public class GridLoggerProxy implements IgniteLogger, LifecycleAware, Externaliz
     @Override public IgniteLogger getLogger(Object ctgr) {
         assert ctgr != null;
 
-        return new GridLoggerProxy(impl.getLogger(ctgr), ctgr, gridName, id8);
+        return new GridLoggerProxy(impl.getLogger(ctgr), ctgr, igniteInstanceName, id8);
     }
 
     /** {@inheritDoc} */
@@ -167,19 +169,20 @@ public class GridLoggerProxy implements IgniteLogger, LifecycleAware, Externaliz
     }
 
     /**
-     * Enriches the log message with grid name if {@link org.apache.ignite.IgniteSystemProperties#IGNITE_LOG_GRID_NAME}
-     * system property is set.
+     * Enriches the log message with Ignite instance name if
+     * {@link org.apache.ignite.IgniteSystemProperties#IGNITE_LOG_INSTANCE_NAME} or
+     * {@link org.apache.ignite.IgniteSystemProperties#IGNITE_LOG_GRID_NAME} system property is set.
      *
      * @param m Message to enrich.
      * @return Enriched message or the original one.
      */
     private String enrich(@Nullable String m) {
-        return logGridName && m != null ? "<" + gridName + '-' + id8 + "> " + m : m;
+        return logIgniteInstanceName && m != null ? "<" + igniteInstanceName + '-' + id8 + "> " + m : m;
     }
 
     /** {@inheritDoc} */
     @Override public void writeExternal(ObjectOutput out) throws IOException {
-        U.writeString(out, gridName);
+        U.writeString(out, igniteInstanceName);
         out.writeObject(ctgr);
     }
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/f59f46d3/modules/core/src/main/java/org/apache/ignite/internal/IgniteKernal.java
----------------------------------------------------------------------
@@ -75,16 +77,16 @@ public class GridLoggerProxy implements IgniteLogger, LifecycleAware, Externaliz
      * @param impl Logger implementation to proxy to.
      * @param ctgr Optional logger category.
-     * @param gridName Grid name (can be {@code null} for default grid).
+     * @param igniteInstanceName Ignite instance name (can be {@code null} for default grid).
      * @param id8 Node ID.
      */